# power-ml

Empowerment Python Machine Learing Stack.

## Install

* Requirements
   * Poetry
   * pyenv

```sh
poetry install --no-dev
```

## Other Requirements

* lightgbm
   * For LightGBM model.
* boto3
   * For AWS support.
```

## Development

```sh
# Setup
poetry install

# Run lint and test.
bash scripts/report.bash
```
